A toolkit for analyzing CVXPY problems.

Install from source (i.e., clone the repository and run ``python setup.py install``)

Example usage:
```
from cvxpyanalyzer import tech_support

# Construct CVXPY problem.
...

# Analyze the problem.
tech_support(problem)
```
